# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.sheet.accessible_cell import AccessibleCell as AccessibleCell
from ...lo.sheet.accessible_csv_cell import AccessibleCsvCell as AccessibleCsvCell
from ...lo.sheet.accessible_csv_ruler import AccessibleCsvRuler as AccessibleCsvRuler
from ...lo.sheet.accessible_csv_table import AccessibleCsvTable as AccessibleCsvTable
from ...lo.sheet.accessible_page_header_footer_areas_view import AccessiblePageHeaderFooterAreasView as AccessiblePageHeaderFooterAreasView
from ...lo.sheet.accessible_spreadsheet import AccessibleSpreadsheet as AccessibleSpreadsheet
from ...lo.sheet.accessible_spreadsheet_document_view import AccessibleSpreadsheetDocumentView as AccessibleSpreadsheetDocumentView
from ...lo.sheet.accessible_spreadsheet_page_view import AccessibleSpreadsheetPageView as AccessibleSpreadsheetPageView
from ...lo.sheet.activation_event import ActivationEvent as ActivationEvent
from ...lo.sheet.add_in import AddIn as AddIn
from ...lo.sheet.address_convention import AddressConvention as AddressConvention
from ...lo.sheet.border import Border as Border
from ...lo.sheet.cell_annotation import CellAnnotation as CellAnnotation
from ...lo.sheet.cell_annotation_shape import CellAnnotationShape as CellAnnotationShape
from ...lo.sheet.cell_annotations import CellAnnotations as CellAnnotations
from ...lo.sheet.cell_annotations_enumeration import CellAnnotationsEnumeration as CellAnnotationsEnumeration
from ...lo.sheet.cell_area_link import CellAreaLink as CellAreaLink
from ...lo.sheet.cell_area_links import CellAreaLinks as CellAreaLinks
from ...lo.sheet.cell_area_links_enumeration import CellAreaLinksEnumeration as CellAreaLinksEnumeration
from ...lo.sheet.cell_delete_mode import CellDeleteMode as CellDeleteMode
from ...lo.sheet.cell_flags import CellFlags as CellFlags
from ...lo.sheet.cell_format_ranges import CellFormatRanges as CellFormatRanges
from ...lo.sheet.cell_format_ranges_enumeration import CellFormatRangesEnumeration as CellFormatRangesEnumeration
from ...lo.sheet.cell_insert_mode import CellInsertMode as CellInsertMode
from ...lo.sheet.cells import Cells as Cells
from ...lo.sheet.cells_enumeration import CellsEnumeration as CellsEnumeration
from ...lo.sheet.color_scale import ColorScale as ColorScale
from ...lo.sheet.color_scale_entry_type import ColorScaleEntryType as ColorScaleEntryType
from ...lo.sheet.complex_reference import ComplexReference as ComplexReference
from ...lo.sheet.condition_entry_type import ConditionEntryType as ConditionEntryType
from ...lo.sheet.condition_format_entry import ConditionFormatEntry as ConditionFormatEntry
from ...lo.sheet.condition_format_operator import ConditionFormatOperator as ConditionFormatOperator
from ...lo.sheet.condition_operator import ConditionOperator as ConditionOperator
from ...lo.sheet.condition_operator2 import ConditionOperator2 as ConditionOperator2
from ...lo.sheet.conditional_format import ConditionalFormat as ConditionalFormat
from ...lo.sheet.consolidation_descriptor import ConsolidationDescriptor as ConsolidationDescriptor
from ...lo.sheet.dde_item_info import DDEItemInfo as DDEItemInfo
from ...lo.sheet.dde_link import DDELink as DDELink
from ...lo.sheet.dde_link_info import DDELinkInfo as DDELinkInfo
from ...lo.sheet.dde_link_mode import DDELinkMode as DDELinkMode
from ...lo.sheet.dde_links import DDELinks as DDELinks
from ...lo.sheet.dde_links_enumeration import DDELinksEnumeration as DDELinksEnumeration
from ...lo.sheet.data_bar import DataBar as DataBar
from ...lo.sheet.data_bar_axis import DataBarAxis as DataBarAxis
from ...lo.sheet.data_bar_entry_type import DataBarEntryType as DataBarEntryType
from ...lo.sheet.data_import_mode import DataImportMode as DataImportMode
from ...lo.sheet.data_pilot_descriptor import DataPilotDescriptor as DataPilotDescriptor
from ...lo.sheet.data_pilot_field import DataPilotField as DataPilotField
from ...lo.sheet.data_pilot_field_auto_show_info import DataPilotFieldAutoShowInfo as DataPilotFieldAutoShowInfo
from ...lo.sheet.data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter
from ...lo.sheet.data_pilot_field_group import DataPilotFieldGroup as DataPilotFieldGroup
from ...lo.sheet.data_pilot_field_group_by import DataPilotFieldGroupBy as DataPilotFieldGroupBy
from ...lo.sheet.data_pilot_field_group_enumeration import DataPilotFieldGroupEnumeration as DataPilotFieldGroupEnumeration
from ...lo.sheet.data_pilot_field_group_info import DataPilotFieldGroupInfo as DataPilotFieldGroupInfo
from ...lo.sheet.data_pilot_field_group_item import DataPilotFieldGroupItem as DataPilotFieldGroupItem
from ...lo.sheet.data_pilot_field_groups import DataPilotFieldGroups as DataPilotFieldGroups
from ...lo.sheet.data_pilot_field_groups_enumeration import DataPilotFieldGroupsEnumeration as DataPilotFieldGroupsEnumeration
from ...lo.sheet.data_pilot_field_layout_info import DataPilotFieldLayoutInfo as DataPilotFieldLayoutInfo
from ...lo.sheet.data_pilot_field_layout_mode import DataPilotFieldLayoutMode as DataPilotFieldLayoutMode
from ...lo.sheet.data_pilot_field_orientation import DataPilotFieldOrientation as DataPilotFieldOrientation
from ...lo.sheet.data_pilot_field_reference import DataPilotFieldReference as DataPilotFieldReference
from ...lo.sheet.data_pilot_field_reference_item_type import DataPilotFieldReferenceItemType as DataPilotFieldReferenceItemType
from ...lo.sheet.data_pilot_field_reference_type import DataPilotFieldReferenceType as DataPilotFieldReferenceType
from ...lo.sheet.data_pilot_field_show_items_mode import DataPilotFieldShowItemsMode as DataPilotFieldShowItemsMode
from ...lo.sheet.data_pilot_field_sort_info import DataPilotFieldSortInfo as DataPilotFieldSortInfo
from ...lo.sheet.data_pilot_field_sort_mode import DataPilotFieldSortMode as DataPilotFieldSortMode
from ...lo.sheet.data_pilot_fields import DataPilotFields as DataPilotFields
from ...lo.sheet.data_pilot_fields_enumeration import DataPilotFieldsEnumeration as DataPilotFieldsEnumeration
from ...lo.sheet.data_pilot_item import DataPilotItem as DataPilotItem
from ...lo.sheet.data_pilot_items import DataPilotItems as DataPilotItems
from ...lo.sheet.data_pilot_items_enumeration import DataPilotItemsEnumeration as DataPilotItemsEnumeration
from ...lo.sheet.data_pilot_output_range_type import DataPilotOutputRangeType as DataPilotOutputRangeType
from ...lo.sheet.data_pilot_source import DataPilotSource as DataPilotSource
from ...lo.sheet.data_pilot_source_dimension import DataPilotSourceDimension as DataPilotSourceDimension
from ...lo.sheet.data_pilot_source_dimensions import DataPilotSourceDimensions as DataPilotSourceDimensions
from ...lo.sheet.data_pilot_source_hierarchies import DataPilotSourceHierarchies as DataPilotSourceHierarchies
from ...lo.sheet.data_pilot_source_hierarchy import DataPilotSourceHierarchy as DataPilotSourceHierarchy
from ...lo.sheet.data_pilot_source_level import DataPilotSourceLevel as DataPilotSourceLevel
from ...lo.sheet.data_pilot_source_levels import DataPilotSourceLevels as DataPilotSourceLevels
from ...lo.sheet.data_pilot_source_member import DataPilotSourceMember as DataPilotSourceMember
from ...lo.sheet.data_pilot_source_members import DataPilotSourceMembers as DataPilotSourceMembers
from ...lo.sheet.data_pilot_table import DataPilotTable as DataPilotTable
from ...lo.sheet.data_pilot_table_header_data import DataPilotTableHeaderData as DataPilotTableHeaderData
from ...lo.sheet.data_pilot_table_position_data import DataPilotTablePositionData as DataPilotTablePositionData
from ...lo.sheet.data_pilot_table_position_type import DataPilotTablePositionType as DataPilotTablePositionType
from ...lo.sheet.data_pilot_table_result_data import DataPilotTableResultData as DataPilotTableResultData
from ...lo.sheet.data_pilot_tables import DataPilotTables as DataPilotTables
from ...lo.sheet.data_pilot_tables_enumeration import DataPilotTablesEnumeration as DataPilotTablesEnumeration
from ...lo.sheet.data_result import DataResult as DataResult
from ...lo.sheet.data_result_flags import DataResultFlags as DataResultFlags
from ...lo.sheet.database_import_descriptor import DatabaseImportDescriptor as DatabaseImportDescriptor
from ...lo.sheet.database_range import DatabaseRange as DatabaseRange
from ...lo.sheet.database_ranges import DatabaseRanges as DatabaseRanges
from ...lo.sheet.database_ranges_enumeration import DatabaseRangesEnumeration as DatabaseRangesEnumeration
from ...lo.sheet.date_condition import DateCondition as DateCondition
from ...lo.sheet.date_type import DateType as DateType
from ...lo.sheet.dimension_flags import DimensionFlags as DimensionFlags
from ...lo.sheet.document_settings import DocumentSettings as DocumentSettings
from ...lo.sheet.external_doc_link import ExternalDocLink as ExternalDocLink
from ...lo.sheet.external_doc_links import ExternalDocLinks as ExternalDocLinks
from ...lo.sheet.external_link_info import ExternalLinkInfo as ExternalLinkInfo
from ...lo.sheet.external_link_type import ExternalLinkType as ExternalLinkType
from ...lo.sheet.external_reference import ExternalReference as ExternalReference
from ...lo.sheet.external_sheet_cache import ExternalSheetCache as ExternalSheetCache
from ...lo.sheet.fill_date_mode import FillDateMode as FillDateMode
from ...lo.sheet.fill_direction import FillDirection as FillDirection
from ...lo.sheet.fill_mode import FillMode as FillMode
from ...lo.sheet.filter_connection import FilterConnection as FilterConnection
from ...lo.sheet.filter_field_type import FilterFieldType as FilterFieldType
from ...lo.sheet.filter_field_value import FilterFieldValue as FilterFieldValue
from ...lo.sheet.filter_formula_parser import FilterFormulaParser as FilterFormulaParser
from ...lo.sheet.filter_operator import FilterOperator as FilterOperator
from ...lo.sheet.filter_operator2 import FilterOperator2 as FilterOperator2
from ...lo.sheet.formula_language import FormulaLanguage as FormulaLanguage
from ...lo.sheet.formula_map_group import FormulaMapGroup as FormulaMapGroup
from ...lo.sheet.formula_map_group_special_offset import FormulaMapGroupSpecialOffset as FormulaMapGroupSpecialOffset
from ...lo.sheet.formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry
from ...lo.sheet.formula_op_code_mapper import FormulaOpCodeMapper as FormulaOpCodeMapper
from ...lo.sheet.formula_parser import FormulaParser as FormulaParser
from ...lo.sheet.formula_result import FormulaResult as FormulaResult
from ...lo.sheet.formula_token import FormulaToken as FormulaToken
from ...lo.sheet.function_access import FunctionAccess as FunctionAccess
from ...lo.sheet.function_argument import FunctionArgument as FunctionArgument
from ...lo.sheet.function_category import FunctionCategory as FunctionCategory
from ...lo.sheet.function_description import FunctionDescription as FunctionDescription
from ...lo.sheet.function_description_enumeration import FunctionDescriptionEnumeration as FunctionDescriptionEnumeration
from ...lo.sheet.function_descriptions import FunctionDescriptions as FunctionDescriptions
from ...lo.sheet.general_function import GeneralFunction as GeneralFunction
from ...lo.sheet.general_function2 import GeneralFunction2 as GeneralFunction2
from ...lo.sheet.global_sheet_settings import GlobalSheetSettings as GlobalSheetSettings
from ...lo.sheet.goal_result import GoalResult as GoalResult
from ...lo.sheet.header_footer_content import HeaderFooterContent as HeaderFooterContent
from ...lo.sheet.icon_set import IconSet as IconSet
from ...lo.sheet.icon_set_format_entry import IconSetFormatEntry as IconSetFormatEntry
from ...lo.sheet.icon_set_type import IconSetType as IconSetType
from ...lo.sheet.label_range import LabelRange as LabelRange
from ...lo.sheet.label_ranges import LabelRanges as LabelRanges
from ...lo.sheet.label_ranges_enumeration import LabelRangesEnumeration as LabelRangesEnumeration
from ...lo.sheet.localized_name import LocalizedName as LocalizedName
from ...lo.sheet.member_result import MemberResult as MemberResult
from ...lo.sheet.member_result_flags import MemberResultFlags as MemberResultFlags
from ...lo.sheet.move_direction import MoveDirection as MoveDirection
from ...lo.sheet.name_token import NameToken as NameToken
from ...lo.sheet.named_range import NamedRange as NamedRange
from ...lo.sheet.named_range_flag import NamedRangeFlag as NamedRangeFlag
from ...lo.sheet.named_ranges import NamedRanges as NamedRanges
from ...lo.sheet.named_ranges_enumeration import NamedRangesEnumeration as NamedRangesEnumeration
from ...lo.sheet.no_convergence_exception import NoConvergenceException as NoConvergenceException
from ...lo.sheet.paste_operation import PasteOperation as PasteOperation
from ...lo.sheet.range_selection_arguments import RangeSelectionArguments as RangeSelectionArguments
from ...lo.sheet.range_selection_event import RangeSelectionEvent as RangeSelectionEvent
from ...lo.sheet.recent_functions import RecentFunctions as RecentFunctions
from ...lo.sheet.reference_flags import ReferenceFlags as ReferenceFlags
from ...lo.sheet.result_event import ResultEvent as ResultEvent
from ...lo.sheet.scenario import Scenario as Scenario
from ...lo.sheet.scenarios import Scenarios as Scenarios
from ...lo.sheet.scenarios_enumeration import ScenariosEnumeration as ScenariosEnumeration
from ...lo.sheet.shape import Shape as Shape
from ...lo.sheet.sheet_cell import SheetCell as SheetCell
from ...lo.sheet.sheet_cell_cursor import SheetCellCursor as SheetCellCursor
from ...lo.sheet.sheet_cell_range import SheetCellRange as SheetCellRange
from ...lo.sheet.sheet_cell_ranges import SheetCellRanges as SheetCellRanges
from ...lo.sheet.sheet_cell_ranges_enumeration import SheetCellRangesEnumeration as SheetCellRangesEnumeration
from ...lo.sheet.sheet_filter_descriptor import SheetFilterDescriptor as SheetFilterDescriptor
from ...lo.sheet.sheet_link import SheetLink as SheetLink
from ...lo.sheet.sheet_link_mode import SheetLinkMode as SheetLinkMode
from ...lo.sheet.sheet_links import SheetLinks as SheetLinks
from ...lo.sheet.sheet_links_enumeration import SheetLinksEnumeration as SheetLinksEnumeration
from ...lo.sheet.sheet_ranges_query import SheetRangesQuery as SheetRangesQuery
from ...lo.sheet.sheet_sort_descriptor import SheetSortDescriptor as SheetSortDescriptor
from ...lo.sheet.sheet_sort_descriptor2 import SheetSortDescriptor2 as SheetSortDescriptor2
from ...lo.sheet.single_reference import SingleReference as SingleReference
from ...lo.sheet.solver import Solver as Solver
from ...lo.sheet.solver_constraint import SolverConstraint as SolverConstraint
from ...lo.sheet.solver_constraint_operator import SolverConstraintOperator as SolverConstraintOperator
from ...lo.sheet.spreadsheet import Spreadsheet as Spreadsheet
from ...lo.sheet.spreadsheet_document import SpreadsheetDocument as SpreadsheetDocument
from ...lo.sheet.spreadsheet_document_settings import SpreadsheetDocumentSettings as SpreadsheetDocumentSettings
from ...lo.sheet.spreadsheet_draw_page import SpreadsheetDrawPage as SpreadsheetDrawPage
from ...lo.sheet.spreadsheet_view import SpreadsheetView as SpreadsheetView
from ...lo.sheet.spreadsheet_view_objects_mode import SpreadsheetViewObjectsMode as SpreadsheetViewObjectsMode
from ...lo.sheet.spreadsheet_view_pane import SpreadsheetViewPane as SpreadsheetViewPane
from ...lo.sheet.spreadsheet_view_panes_enumeration import SpreadsheetViewPanesEnumeration as SpreadsheetViewPanesEnumeration
from ...lo.sheet.spreadsheet_view_settings import SpreadsheetViewSettings as SpreadsheetViewSettings
from ...lo.sheet.spreadsheets import Spreadsheets as Spreadsheets
from ...lo.sheet.spreadsheets_enumeration import SpreadsheetsEnumeration as SpreadsheetsEnumeration
from ...lo.sheet.status_bar_function import StatusBarFunction as StatusBarFunction
from ...lo.sheet.sub_total_column import SubTotalColumn as SubTotalColumn
from ...lo.sheet.sub_total_descriptor import SubTotalDescriptor as SubTotalDescriptor
from ...lo.sheet.sub_total_field import SubTotalField as SubTotalField
from ...lo.sheet.sub_total_fields_enumeration import SubTotalFieldsEnumeration as SubTotalFieldsEnumeration
from ...lo.sheet.table_auto_format import TableAutoFormat as TableAutoFormat
from ...lo.sheet.table_auto_format_enumeration import TableAutoFormatEnumeration as TableAutoFormatEnumeration
from ...lo.sheet.table_auto_format_field import TableAutoFormatField as TableAutoFormatField
from ...lo.sheet.table_auto_formats import TableAutoFormats as TableAutoFormats
from ...lo.sheet.table_auto_formats_enumeration import TableAutoFormatsEnumeration as TableAutoFormatsEnumeration
from ...lo.sheet.table_cell_style import TableCellStyle as TableCellStyle
from ...lo.sheet.table_conditional_entry import TableConditionalEntry as TableConditionalEntry
from ...lo.sheet.table_conditional_entry_enumeration import TableConditionalEntryEnumeration as TableConditionalEntryEnumeration
from ...lo.sheet.table_conditional_format import TableConditionalFormat as TableConditionalFormat
from ...lo.sheet.table_filter_field import TableFilterField as TableFilterField
from ...lo.sheet.table_filter_field2 import TableFilterField2 as TableFilterField2
from ...lo.sheet.table_filter_field3 import TableFilterField3 as TableFilterField3
from ...lo.sheet.table_operation_mode import TableOperationMode as TableOperationMode
from ...lo.sheet.table_page_break_data import TablePageBreakData as TablePageBreakData
from ...lo.sheet.table_page_style import TablePageStyle as TablePageStyle
from ...lo.sheet.table_validation import TableValidation as TableValidation
from ...lo.sheet.table_validation_visibility import TableValidationVisibility as TableValidationVisibility
from ...lo.sheet.unique_cell_format_ranges import UniqueCellFormatRanges as UniqueCellFormatRanges
from ...lo.sheet.unique_cell_format_ranges_enumeration import UniqueCellFormatRangesEnumeration as UniqueCellFormatRangesEnumeration
from ...lo.sheet.validation_alert_style import ValidationAlertStyle as ValidationAlertStyle
from ...lo.sheet.validation_type import ValidationType as ValidationType
from ...lo.sheet.volatile_result import VolatileResult as VolatileResult
from ...lo.sheet.x_activation_broadcaster import XActivationBroadcaster as XActivationBroadcaster
from ...lo.sheet.x_activation_event_listener import XActivationEventListener as XActivationEventListener
from ...lo.sheet.x_add_in import XAddIn as XAddIn
from ...lo.sheet.x_area_link import XAreaLink as XAreaLink
from ...lo.sheet.x_area_links import XAreaLinks as XAreaLinks
from ...lo.sheet.x_array_formula_range import XArrayFormulaRange as XArrayFormulaRange
from ...lo.sheet.x_array_formula_tokens import XArrayFormulaTokens as XArrayFormulaTokens
from ...lo.sheet.x_calculatable import XCalculatable as XCalculatable
from ...lo.sheet.x_cell_addressable import XCellAddressable as XCellAddressable
from ...lo.sheet.x_cell_format_ranges_supplier import XCellFormatRangesSupplier as XCellFormatRangesSupplier
from ...lo.sheet.x_cell_range_addressable import XCellRangeAddressable as XCellRangeAddressable
from ...lo.sheet.x_cell_range_data import XCellRangeData as XCellRangeData
from ...lo.sheet.x_cell_range_formula import XCellRangeFormula as XCellRangeFormula
from ...lo.sheet.x_cell_range_movement import XCellRangeMovement as XCellRangeMovement
from ...lo.sheet.x_cell_range_referrer import XCellRangeReferrer as XCellRangeReferrer
from ...lo.sheet.x_cell_ranges_access import XCellRangesAccess as XCellRangesAccess
from ...lo.sheet.x_cell_ranges_query import XCellRangesQuery as XCellRangesQuery
from ...lo.sheet.x_cell_series import XCellSeries as XCellSeries
from ...lo.sheet.x_color_scale_entry import XColorScaleEntry as XColorScaleEntry
from ...lo.sheet.x_compatibility_names import XCompatibilityNames as XCompatibilityNames
from ...lo.sheet.x_condition_entry import XConditionEntry as XConditionEntry
from ...lo.sheet.x_conditional_format import XConditionalFormat as XConditionalFormat
from ...lo.sheet.x_conditional_formats import XConditionalFormats as XConditionalFormats
from ...lo.sheet.x_consolidatable import XConsolidatable as XConsolidatable
from ...lo.sheet.x_consolidation_descriptor import XConsolidationDescriptor as XConsolidationDescriptor
from ...lo.sheet.xdde_link import XDDELink as XDDELink
from ...lo.sheet.xdde_link_results import XDDELinkResults as XDDELinkResults
from ...lo.sheet.xdde_links import XDDELinks as XDDELinks
from ...lo.sheet.x_data_bar_entry import XDataBarEntry as XDataBarEntry
from ...lo.sheet.x_data_pilot_data_layout_field_supplier import XDataPilotDataLayoutFieldSupplier as XDataPilotDataLayoutFieldSupplier
from ...lo.sheet.x_data_pilot_descriptor import XDataPilotDescriptor as XDataPilotDescriptor
from ...lo.sheet.x_data_pilot_field import XDataPilotField as XDataPilotField
from ...lo.sheet.x_data_pilot_field_grouping import XDataPilotFieldGrouping as XDataPilotFieldGrouping
from ...lo.sheet.x_data_pilot_member_results import XDataPilotMemberResults as XDataPilotMemberResults
from ...lo.sheet.x_data_pilot_results import XDataPilotResults as XDataPilotResults
from ...lo.sheet.x_data_pilot_table import XDataPilotTable as XDataPilotTable
from ...lo.sheet.x_data_pilot_table2 import XDataPilotTable2 as XDataPilotTable2
from ...lo.sheet.x_data_pilot_tables import XDataPilotTables as XDataPilotTables
from ...lo.sheet.x_data_pilot_tables_supplier import XDataPilotTablesSupplier as XDataPilotTablesSupplier
from ...lo.sheet.x_database_range import XDatabaseRange as XDatabaseRange
from ...lo.sheet.x_database_ranges import XDatabaseRanges as XDatabaseRanges
from ...lo.sheet.x_dimensions_supplier import XDimensionsSupplier as XDimensionsSupplier
from ...lo.sheet.x_document_auditing import XDocumentAuditing as XDocumentAuditing
from ...lo.sheet.x_drill_down_data_supplier import XDrillDownDataSupplier as XDrillDownDataSupplier
from ...lo.sheet.x_enhanced_mouse_click_broadcaster import XEnhancedMouseClickBroadcaster as XEnhancedMouseClickBroadcaster
from ...lo.sheet.x_external_doc_link import XExternalDocLink as XExternalDocLink
from ...lo.sheet.x_external_doc_links import XExternalDocLinks as XExternalDocLinks
from ...lo.sheet.x_external_sheet_cache import XExternalSheetCache as XExternalSheetCache
from ...lo.sheet.x_external_sheet_name import XExternalSheetName as XExternalSheetName
from ...lo.sheet.x_fill_across_sheet import XFillAcrossSheet as XFillAcrossSheet
from ...lo.sheet.x_filter_formula_parser import XFilterFormulaParser as XFilterFormulaParser
from ...lo.sheet.x_formula_op_code_mapper import XFormulaOpCodeMapper as XFormulaOpCodeMapper
from ...lo.sheet.x_formula_parser import XFormulaParser as XFormulaParser
from ...lo.sheet.x_formula_query import XFormulaQuery as XFormulaQuery
from ...lo.sheet.x_formula_tokens import XFormulaTokens as XFormulaTokens
from ...lo.sheet.x_function_access import XFunctionAccess as XFunctionAccess
from ...lo.sheet.x_function_descriptions import XFunctionDescriptions as XFunctionDescriptions
from ...lo.sheet.x_global_sheet_settings import XGlobalSheetSettings as XGlobalSheetSettings
from ...lo.sheet.x_goal_seek import XGoalSeek as XGoalSeek
from ...lo.sheet.x_header_footer_content import XHeaderFooterContent as XHeaderFooterContent
from ...lo.sheet.x_hierarchies_supplier import XHierarchiesSupplier as XHierarchiesSupplier
from ...lo.sheet.x_icon_set_entry import XIconSetEntry as XIconSetEntry
from ...lo.sheet.x_label_range import XLabelRange as XLabelRange
from ...lo.sheet.x_label_ranges import XLabelRanges as XLabelRanges
from ...lo.sheet.x_levels_supplier import XLevelsSupplier as XLevelsSupplier
from ...lo.sheet.x_members_access import XMembersAccess as XMembersAccess
from ...lo.sheet.x_members_supplier import XMembersSupplier as XMembersSupplier
from ...lo.sheet.x_multi_formula_tokens import XMultiFormulaTokens as XMultiFormulaTokens
from ...lo.sheet.x_multiple_operation import XMultipleOperation as XMultipleOperation
from ...lo.sheet.x_named_range import XNamedRange as XNamedRange
from ...lo.sheet.x_named_ranges import XNamedRanges as XNamedRanges
from ...lo.sheet.x_print_areas import XPrintAreas as XPrintAreas
from ...lo.sheet.x_range_selection import XRangeSelection as XRangeSelection
from ...lo.sheet.x_range_selection_change_listener import XRangeSelectionChangeListener as XRangeSelectionChangeListener
from ...lo.sheet.x_range_selection_listener import XRangeSelectionListener as XRangeSelectionListener
from ...lo.sheet.x_recent_functions import XRecentFunctions as XRecentFunctions
from ...lo.sheet.x_result_listener import XResultListener as XResultListener
from ...lo.sheet.x_scenario import XScenario as XScenario
from ...lo.sheet.x_scenario_enhanced import XScenarioEnhanced as XScenarioEnhanced
from ...lo.sheet.x_scenarios import XScenarios as XScenarios
from ...lo.sheet.x_scenarios_supplier import XScenariosSupplier as XScenariosSupplier
from ...lo.sheet.x_selected_sheets_supplier import XSelectedSheetsSupplier as XSelectedSheetsSupplier
from ...lo.sheet.x_sheet_annotation import XSheetAnnotation as XSheetAnnotation
from ...lo.sheet.x_sheet_annotation_anchor import XSheetAnnotationAnchor as XSheetAnnotationAnchor
from ...lo.sheet.x_sheet_annotation_shape_supplier import XSheetAnnotationShapeSupplier as XSheetAnnotationShapeSupplier
from ...lo.sheet.x_sheet_annotations import XSheetAnnotations as XSheetAnnotations
from ...lo.sheet.x_sheet_annotations_supplier import XSheetAnnotationsSupplier as XSheetAnnotationsSupplier
from ...lo.sheet.x_sheet_auditing import XSheetAuditing as XSheetAuditing
from ...lo.sheet.x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor
from ...lo.sheet.x_sheet_cell_range import XSheetCellRange as XSheetCellRange
from ...lo.sheet.x_sheet_cell_range_container import XSheetCellRangeContainer as XSheetCellRangeContainer
from ...lo.sheet.x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges
from ...lo.sheet.x_sheet_condition import XSheetCondition as XSheetCondition
from ...lo.sheet.x_sheet_condition2 import XSheetCondition2 as XSheetCondition2
from ...lo.sheet.x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries
from ...lo.sheet.x_sheet_conditional_entry import XSheetConditionalEntry as XSheetConditionalEntry
from ...lo.sheet.x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor
from ...lo.sheet.x_sheet_filter_descriptor2 import XSheetFilterDescriptor2 as XSheetFilterDescriptor2
from ...lo.sheet.x_sheet_filter_descriptor3 import XSheetFilterDescriptor3 as XSheetFilterDescriptor3
from ...lo.sheet.x_sheet_filterable import XSheetFilterable as XSheetFilterable
from ...lo.sheet.x_sheet_filterable_ex import XSheetFilterableEx as XSheetFilterableEx
from ...lo.sheet.x_sheet_linkable import XSheetLinkable as XSheetLinkable
from ...lo.sheet.x_sheet_operation import XSheetOperation as XSheetOperation
from ...lo.sheet.x_sheet_outline import XSheetOutline as XSheetOutline
from ...lo.sheet.x_sheet_page_break import XSheetPageBreak as XSheetPageBreak
from ...lo.sheet.x_sheet_pastable import XSheetPastable as XSheetPastable
from ...lo.sheet.x_solver import XSolver as XSolver
from ...lo.sheet.x_solver_description import XSolverDescription as XSolverDescription
from ...lo.sheet.x_spreadsheet import XSpreadsheet as XSpreadsheet
from ...lo.sheet.x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument
from ...lo.sheet.x_spreadsheet_view import XSpreadsheetView as XSpreadsheetView
from ...lo.sheet.x_spreadsheets import XSpreadsheets as XSpreadsheets
from ...lo.sheet.x_spreadsheets2 import XSpreadsheets2 as XSpreadsheets2
from ...lo.sheet.x_sub_total_calculatable import XSubTotalCalculatable as XSubTotalCalculatable
from ...lo.sheet.x_sub_total_descriptor import XSubTotalDescriptor as XSubTotalDescriptor
from ...lo.sheet.x_sub_total_field import XSubTotalField as XSubTotalField
from ...lo.sheet.x_unique_cell_format_ranges_supplier import XUniqueCellFormatRangesSupplier as XUniqueCellFormatRangesSupplier
from ...lo.sheet.x_unnamed_database_ranges import XUnnamedDatabaseRanges as XUnnamedDatabaseRanges
from ...lo.sheet.x_used_area_cursor import XUsedAreaCursor as XUsedAreaCursor
from ...lo.sheet.x_view_freezable import XViewFreezable as XViewFreezable
from ...lo.sheet.x_view_pane import XViewPane as XViewPane
from ...lo.sheet.x_view_panes_supplier import XViewPanesSupplier as XViewPanesSupplier
from ...lo.sheet.x_view_splitable import XViewSplitable as XViewSplitable
from ...lo.sheet.x_volatile_result import XVolatileResult as XVolatileResult



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .inserted_object_info import InsertedObjectInfo as InsertedObjectInfo_a0e0e26
    from .x_storage import XStorage as XStorage_8e460a32

class XInsertObjectDialog(XInterface_8f010a43):
    """
    allows to create and initialize a new embedded object using GUI dialog.

    See Also:
        `API XInsertObjectDialog <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XInsertObjectDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XInsertObjectDialog'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XInsertObjectDialog'

    @abstractmethod
    def createInstanceByDialog(self, xStorage: XStorage_8e460a32, sEntName: str, lObjArgs: typing.Tuple[PropertyValue_c9610c73, ...]) -> InsertedObjectInfo_a0e0e26:
        """
        creates a new object using GUI dialog.
        
        The dialog allows for user to do a number of choices that are container related. This information will be returned in the InsertedObjectInfo object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XInsertObjectDialog']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from com.sun.star.sheet.SheetLinkMode import SheetLinkModeProto  # type: ignore
    from com.sun.star.sheet.SheetLinkMode import SheetLinkModeProto  # type: ignore
    from com.sun.star.sheet.SheetLinkMode import SheetLinkModeProto  # type: ignore

class XSheetLinkable(XInterface_8f010a43):
    """
    enables a sheet to refer to another sheet in a different document.
    
    To insert a sheet link, the sheet used as linked sheet has to exist already. The method XSheetLinkable.link() creates a SheetLink object in the document's SheetLinks collection and links the sheet to the specified external sheet.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XSheetLinkable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetLinkable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetLinkable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetLinkable'

    @abstractmethod
    def getLinkMode(self) -> SheetLinkModeProto:
        """
        returns the link mode of the spreadsheet.
        
        If the returned value is SheetLinkMode.NORMAL, formulas are copied. With SheetLinkMode.VALUE, only results of formulas are used.
        """
        ...
    @abstractmethod
    def getLinkSheetName(self) -> str:
        """
        returns the sheet name of the sheet in the source document.
        """
        ...
    @abstractmethod
    def getLinkUrl(self) -> str:
        """
        returns the target URL of the link.
        """
        ...
    @abstractmethod
    def link(self, aUrl: str, aSheetName: str, aFilterName: str, aFilterOptions: str, nMode: SheetLinkModeProto) -> None:
        """
        links the sheet to another sheet in another document.
        
        A SheetLink object is created if it does not exist, and the link mode, the URL of the linked document and the linked sheet name are set.
        """
        ...
    @abstractmethod
    def setLinkMode(self, nLinkMode: SheetLinkModeProto) -> None:
        """
        enables the linking of the sheet and controls whether formulas are copied.
        
        If the value is SheetLinkMode.NORMAL, formulas are copied. With SheetLinkMode.VALUE, only results of formulas are used.
        """
        ...
    @abstractmethod
    def setLinkSheetName(self, aLinkSheetName: str) -> None:
        """
        sets the name of the linked sheet in the source document.
        
        This method sets the sheet name in the SheetLink object, it does not modify the sheet name in the source document.
        """
        ...
    @abstractmethod
    def setLinkUrl(self, aLinkUrl: str) -> None:
        """
        sets the target URL of the link.
        
        A SheetLink object with the same file name must exist already or the link will not work.
        """
        ...

__all__ = ['XSheetLinkable']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSubToolbarController(XInterface_8f010a43):
    """
    special interface to support sub-toolbars in a controller implementation.
    
    This interface is normally used to implement the toolbar button/sub- toolbar function feature. It exchanges the function of the toolbar button, that opened the sub-toolbar, with the one that has been selected on the sub-toolbar.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XSubToolbarController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XSubToolbarController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XSubToolbarController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XSubToolbarController'

    @abstractmethod
    def functionSelected(self, aCommand: str) -> None:
        """
        gets called to notify a controller that a sub-toolbar function has been selected.
        """
        ...
    @abstractmethod
    def getSubToolbarName(self) -> str:
        """
        provides the resource URL of the sub-toolbar this controller opens.
        """
        ...
    @abstractmethod
    def opensSubToolbar(self) -> bool:
        """
        if the controller features a sub-toolbar.
        
        Enables implementations to dynamically decide to support sub-toolbars or not.
        """
        ...
    @abstractmethod
    def updateImage(self) -> None:
        """
        gets called to notify a controller that it should set an image which represents the current selected function.
        
        Only the controller instance is able to set the correct image for the current function. A toolbar implementation will ask sub-toolbar controllers to update their image whenever it has to update the images of all its buttons.
        """
        ...

__all__ = ['XSubToolbarController']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class RuleAction(metaclass=UnoConstMeta, type_name="com.sun.star.ucb.RuleAction", name_space="com.sun.star.ucb"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ucb.RuleAction``"""
        pass

    class RuleActionEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ucb.RuleAction", name_space="com.sun.star.ucb"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ucb.RuleAction`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ucb import RuleAction as RuleAction
    else:
        # keep document generators happy
        from ...lo.ucb.rule_action import RuleAction as RuleAction

    class RuleActionEnum(IntEnum):
        """
        Enum of Const Class RuleAction

        These are the possible values for Rule.Action.
        """
        NONE = RuleAction.NONE
        """
        \"None\" - Do nothing.
        """
        SHOW = RuleAction.SHOW
        """
        \"Show\" - Shows object when term matches.
        """
        HIDE = RuleAction.HIDE
        """
        \"Hide\" - Hides object when term matches.
        """
        MARK = RuleAction.MARK
        """
        \"Mark\" - Marks object when term matches.
        """
        UNMARK = RuleAction.UNMARK
        """
        \"UnMark\" - Removes mark from object when term matches.
        """
        MARKREAD = RuleAction.MARKREAD
        """
        \"MarkRead\" - Marks object as read when term matches.
        """
        MARKUNREAD = RuleAction.MARKUNREAD
        """
        \"MarkUnRead\" - Marks object as not read when term matches.
        """
        MOVE = RuleAction.MOVE
        """
        \"Move\" - Moves object to Rule.Parameter when term matches.
        """
        COPY = RuleAction.COPY
        """
        \"Copy\" - Copies object to Rule.Parameter when term matches.
        """
        DELETE = RuleAction.DELETE
        """
        \"Delete\" - Deletes object when term matches.
        """
        LINK = RuleAction.LINK
        """
        \"Link\" - Creates a link to Rule.Parameter when term matches.
        """
        FORWARD = RuleAction.FORWARD
        """
        \"Forward\" - Forwards object to Rule.Parameter when term matches.
        """

__all__ = ['RuleAction', 'RuleActionEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from abc import abstractmethod
from ..task.x_interaction_continuation import XInteractionContinuation as XInteractionContinuation_5af0108e

class XInteractionFilterSelect(XInteractionContinuation_5af0108e):
    """
    continuation used by interaction mechanism at filter detection during loading documents
    
    If during loading time the filter can't be detected and wasn't given at calling time, a possible com.sun.star.task.InteractionHandler will be used. (it's a part of used MediaDescriptor) A NoSuchFilterRequest will be used then to start right interaction on that to get a decision which filter should be used for given URL. A possible continuation of that can be this XInteractionFilterSelect. It will transport the decision back to generic filter detection and force using of it. Of course it's possible to abort the loading process by use another continuation com.sun.star.task.XInteractionAbort.

    See Also:
        `API XInteractionFilterSelect <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XInteractionFilterSelect.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XInteractionFilterSelect'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XInteractionFilterSelect'

    @abstractmethod
    def getFilter(self) -> str:
        """
        used by detection to get selected filter
        """
        ...
    @abstractmethod
    def setFilter(self, Name: str) -> None:
        """
        used by interaction to set selected filter
        
        This value must be saved till another one will be set and must be provided on getFilter() for interest users.
        """
        ...

__all__ = ['XInteractionFilterSelect']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report.meta
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from .x_function_category import XFunctionCategory as XFunctionCategory_59e21055
    from ...sheet.function_argument import FunctionArgument as FunctionArgument_f1080daa

class XFunctionDescription(XPropertySet_bc180bfa):
    """
    identifies a XFunctionDescription which allows to retrieve the meta data of all supported functions.

    See Also:
        `API XFunctionDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFunctionDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report.meta'
    __ooo_full_ns__: str = 'com.sun.star.report.meta.XFunctionDescription'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.meta.XFunctionDescription'

    @abstractmethod
    def createFormula(self, arguments: typing.Tuple[str, ...]) -> str:
        """

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractproperty
    def Arguments(self) -> typing.Tuple[FunctionArgument_f1080daa, ...]:
        """
        returns a sequence of localized descriptions of the function's arguments (in the order specified by the function).
        """
        ...

    @abstractproperty
    def Category(self) -> XFunctionCategory_59e21055:
        """
        specifies the category number.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        returns a localized description of the function.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        returns the localized function's name.
        """
        ...

    @abstractproperty
    def Signature(self) -> str:
        """
        returns the signature of the function.
        """
        ...


__all__ = ['XFunctionDescription']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.runtime
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ...lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ...beans.named_value import NamedValue as NamedValue_a37a0af3
    from .feature_state import FeatureState as FeatureState_1c3f0ebb
    from .x_feature_invalidation import XFeatureInvalidation as XFeatureInvalidation_9f4211f4
    from .x_form_controller import XFormController as XFormController_4a570ffe
    from ...sdbc.x_result_set_update import XResultSetUpdate as XResultSetUpdate_e0fb0d0a
    from ...sdbc.x_row_set import XRowSet as XRowSet_7a090960

class XFormOperations(XComponent_98dc0ab5):
    """
    encapsulates operations on a database form.
    
    This instance allows for operations on a user interface form, by saving its clients from various tedious and error-prone operations.
    
    As an example, imagine you have a database form, displayed in some user interface, which you want to move to the next record.It is as easy as calling com.sun.star.sdbc.XResultSet.next() on this form, right? Wrong. First, you need to care for saving the current record, so the user doesn't lose her input. So you need to call com.sun.star.sdbc.XResultSetUpdate.updateRow() or com.sun.star.sdbc.XResultSetUpdate.insertRow(), depending on the form's com.sun.star.sdb.RowSet.IsNew property.But then you're done, right? Wrong, again.When the user just entered some data into one of the form fields, but did not yet leave this field, then the data is not yet committed to the form, not to talk about being committed to the underlying database. So, before everything else, you would need to obtain the active control of the form, and commit it.Now you're done ...
    
    As another example, consider that you want to delete the current record from the form. You have to take into account any com.sun.star.form.XConfirmDeleteListeners registered at the com.sun.star.form.FormController or the com.sun.star.form.component.DataForm.
    
    If you agree that this is ugly to do and maintain, then XFormOperations is for you. It provides an execute() method, which will do all of the above for you; plus some similar convenient wrappers for similar functionality.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XFormOperations <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormOperations.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.XFormOperations'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.runtime.XFormOperations'

    @abstractmethod
    def commitCurrentControl(self) -> bool:
        """
        commits the current control of our controller

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def commitCurrentRecord(self, RecordInserted: bool) -> bool:
        """
        commits the current record of the form

        * ``RecordInserted`` is an out direction argument.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def execute(self, Feature: int) -> None:
        """
        executes the operation associated with the given feature

        Raises:
            : ````
            : ````
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def executeWithArguments(self, Feature: int, Arguments: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        """
        executes the operation associated with the given feature, with passing arguments for execution

        Raises:
            : ````
            : ````
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getState(self, Feature: int) -> FeatureState_1c3f0ebb:
        """
        retrieves the current state of the given feature
        
        You would usually use this to update some user interface to reflect this state. For instance, you could imagine a toolbar button which is associated with a given feature. This button would be enabled if and only if the respective feature is currently available, and be checked if and only if the feature state is a boolean evaluating to TRUE.
        """
        ...
    @abstractmethod
    def isEnabled(self, Feature: int) -> bool:
        """
        determines whether a feature is currently enabled.
        
        Calling this is equivalent to calling getState(), and evaluating the FeatureState.Enabled member.
        """
        ...
    @abstractmethod
    def isInsertionRow(self) -> bool:
        """
        determines whether the form is currently positioned on the insertion row
        
        This is a convenience method only. Calling it is equivalent to examining the com.sun.star.sdb.RowSet.IsNew property of the form.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def isModifiedRow(self) -> bool:
        """
        determines whether the current row of the form is modified
        
        This is a convenience method only. Calling it is equivalent to examining the com.sun.star.sdb.RowSet.IsModified property of the form.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractproperty
    def Controller(self) -> XFormController_4a570ffe:
        """
        provides access to the form controller which the instance is operating on.
        
        Note that it is possible to operate on a user interface form without actually having access to the form controller instance. However, in this case some functionality will not be available. In particular, every feature which relies on the active control of the controller might be of limited use.
        """
        ...

    @abstractproperty
    def Cursor(self) -> XRowSet_7a090960:
        """
        provides access to the cursor of the form the instance is operating on.
        """
        ...

    @abstractproperty
    def FeatureInvalidation(self) -> XFeatureInvalidation_9f4211f4:
        """
        denotes the instance which should be notified about features whose state might have changed.
        
        If this attribute is not NULL, the instance which it denotes will be notified whenever the state of any supported feature might have changed.
        
        For instance, imagine a form whose current row has just been moved to another record, using the execute() method. This means that potentially, the state of all movement-related features might have changed.
        
        Note that the instance does not actually notify changes in the feature states, but only potential changes: It's up to the callee to react on this appropriately. This is since OpenOffice.org's application framework features own mechanisms to cache and invalidate feature states, so we do not burden this implementation here with such mechanisms.
        """
        ...

    @abstractproperty
    def UpdateCursor(self) -> XResultSetUpdate_e0fb0d0a:
        """
        provides access to the update cursor of the form the instance is operating on.
        """
        ...


__all__ = ['XFormOperations']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class FontWidth(object):
    """
    Const Class

    These values are used to specify the width of the characters of a font.
    
    They may be expanded in future versions.

    See Also:
        `API FontWidth <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontWidth.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontWidth'
    __ooo_type_name__: str = 'const'

    DONTKNOW = 0.0
    """
    The width of the font is not specified/known.
    """
    ULTRACONDENSED = 50.0
    """
    The width of the font is condensed to 50%.
    """
    EXTRACONDENSED = 60.0
    """
    The width of the font is condensed to 60%.
    """
    CONDENSED = 75.0
    """
    The width of the font is condensed to 75%.
    """
    SEMICONDENSED = 90.0
    """
    The width of the font is condensed to 90%.
    """
    NORMAL = 100.0
    """
    The width of the font is normal.
    """
    SEMIEXPANDED = 110.0
    """
    The width of the font is expanded to 110%.
    """
    EXPANDED = 150.0
    """
    The width of the font is expanded to 150%.
    """
    EXTRAEXPANDED = 175.0
    """
    The width of the font is expanded to 175%.
    """
    ULTRAEXPANDED = 200.0
    """
    The width of the font is expanded to 200%.
    """

__all__ = ['FontWidth']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.key_stroke import KeyStroke as KeyStroke_84cb09f5

class XAccessibleKeyBinding(XInterface_8f010a43):
    """
    This interface can be used to represent any number of key bindings which then can be associated to a certain action.
    
    There can be zero, one, or more key bindings. Each key binding consists of a sequence of com.sun.star.awt.KeyStroke objects. The association of an action with a key binding is established by the XAccessibleAction interface returning an XAccessibleKeyBinding object.
    
    A key binding describes alternative ways how to invoke an action with pressing one or more keys after each other. Each individual sequence of key strokes
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleKeyBinding <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleKeyBinding.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleKeyBinding'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleKeyBinding'

    @abstractmethod
    def getAccessibleKeyBinding(self, nIndex: int) -> typing.Tuple[KeyStroke_84cb09f5, ...]:
        """
        The returned sequence of key strokes describes one method to invoke the associated action (the one from which you obtained the object at which you called this method) by pressing keys.
        
        The keys specified by each of the returned key strokes have to be pressed at the same time (the Control-key and the A-key for example). The keys of one key stroke have to be released before pressing those of the next. The order of the key strokes in the sequence define the order in which to press them.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getAccessibleKeyBindingCount(self) -> int:
        """
        Return the number of available key bindings.
        """
        ...

__all__ = ['XAccessibleKeyBinding']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..sdbc.x_result_set import XResultSet as XResultSet_98e30aa7


class WelcomeDynamicResultSetStruct(object):
    """
    Struct Class

    This struct is to be contained in the first notification of an XDynamicResultSet.

    See Also:
        `API WelcomeDynamicResultSetStruct <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1WelcomeDynamicResultSetStruct.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.WelcomeDynamicResultSetStruct'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.WelcomeDynamicResultSetStruct'
    """Literal Constant ``com.sun.star.ucb.WelcomeDynamicResultSetStruct``"""

    def __init__(self, Old: typing.Optional[XResultSet_98e30aa7] = None, New: typing.Optional[XResultSet_98e30aa7] = None) -> None:
        """
        Constructor

        Arguments:
            Old (XResultSet, optional): Old value.
            New (XResultSet, optional): New value.
        """
        super().__init__()

        if isinstance(Old, WelcomeDynamicResultSetStruct):
            oth: WelcomeDynamicResultSetStruct = Old
            self.Old = oth.Old
            self.New = oth.New
            return

        kargs = {
            "Old": Old,
            "New": New,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._old = kwargs["Old"]
        self._new = kwargs["New"]


    @property
    def Old(self) -> XResultSet_98e30aa7:
        """
        The static result set containing the previous version of result set data.
        """
        return self._old

    @Old.setter
    def Old(self, value: XResultSet_98e30aa7) -> None:
        self._old = value

    @property
    def New(self) -> XResultSet_98e30aa7:
        """
        The static result set containing the new version of result set data.
        """
        return self._new

    @New.setter
    def New(self, value: XResultSet_98e30aa7) -> None:
        self._new = value


__all__ = ['WelcomeDynamicResultSetStruct']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.csax
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class XMLAttribute(object):
    """
    Struct Class

    A struct to keep information of an element's attribute.

    See Also:
        `API XMLAttribute <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1csax_1_1XMLAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.csax'
    __ooo_full_ns__: str = 'com.sun.star.xml.csax.XMLAttribute'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.csax.XMLAttribute'
    """Literal Constant ``com.sun.star.xml.csax.XMLAttribute``"""

    def __init__(self, sName: typing.Optional[str] = '', sValue: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            sName (str, optional): sName value.
            sValue (str, optional): sValue value.
        """
        super().__init__()

        if isinstance(sName, XMLAttribute):
            oth: XMLAttribute = sName
            self.sName = oth.sName
            self.sValue = oth.sValue
            return

        kargs = {
            "sName": sName,
            "sValue": sValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._s_name = kwargs["sName"]
        self._s_value = kwargs["sValue"]


    @property
    def sName(self) -> str:
        """
        the attribute name
        """
        return self._s_name

    @sName.setter
    def sName(self, value: str) -> None:
        self._s_name = value

    @property
    def sValue(self) -> str:
        """
        the attribute value
        """
        return self._s_value

    @sValue.setter
    def sValue(self, value: str) -> None:
        self._s_value = value


__all__ = ['XMLAttribute']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod
from .xxml_security_template import XXMLSecurityTemplate as XXMLSecurityTemplate_79221105
if typing.TYPE_CHECKING:
    from .x_uri_binding import XUriBinding as XUriBinding_f04e0d6b
    from ..wrapper.xxml_element_wrapper import XXMLElementWrapper as XXMLElementWrapper_66c0107c

class XXMLSignatureTemplate(XXMLSecurityTemplate_79221105):
    """
    Interface of XML signature template.
    
    This interface represents a signature template, which is the same as the desired XML signature element but some of the nodes may be empty. The empty entities include digest value and signature value. Empty entities are not allowed in a signature template when performing validation.
    
    In some cases, the signer or verifier can determine and locate the contents to be signed from the template by dereference the URI.
    
    With the help of signature context, the signer or verifier specifies the key from the KeyInfo in the signature template.

    See Also:
        `API XXMLSignatureTemplate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLSignatureTemplate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XXMLSignatureTemplate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XXMLSignatureTemplate'

    @abstractmethod
    def getBinding(self) -> XUriBinding_f04e0d6b:
        """
        Get the dynamic URI binding.
        """
        ...
    @abstractmethod
    def getTargets(self) -> typing.Tuple[XXMLElementWrapper_66c0107c, ...]:
        """
        Get the target XML element, i.e.
        
        the element to be signed
        """
        ...
    @abstractmethod
    def setBinding(self, aUriBinding: XUriBinding_f04e0d6b) -> None:
        """
        Set the dynamic URI binding.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XXMLSignatureTemplate']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text


class WritingMode2(object):
    """
    Const Class

    this set of constants describes different writing directions
    
    In addition to numerous explicit writing directions, it allows to specify to take the writing direction from the object's context.
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API WritingMode2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.WritingMode2'
    __ooo_type_name__: str = 'const'

    LR_TB = 0
    """
    text within lines is written left-to-right.
    
    Lines and blocks are placed top-to-bottom.
    
    Typically, this is the writing mode for normal \"alphabetic\" text.
    """
    RL_TB = 1
    """
    text within a line are written right-to-left.
    
    Lines and blocks are placed top-to-bottom.
    
    Typically, this writing mode is used in Arabic and Hebrew text.
    """
    TB_RL = 2
    """
    text within a line is written top-to-bottom.
    
    Lines and blocks are placed right-to-left.
    
    Typically, this writing mode is used in Chinese and Japanese text.
    """
    TB_LR = 3
    """
    text within a line is written top-to-bottom.
    
    Lines and blocks are placed left-to-right.
    
    Typically, this writing mode is used in Mongolian text.
    """
    PAGE = 4
    """
    obtain writing mode from the current page.
    
    May not be used in page styles.
    """
    CONTEXT = 4
    """
    obtain actual writing mode from the context of the object.
    """
    BT_LR = 5
    """
    text within a line is written bottom-to-top.
    
    Lines and blocks are placed left-to-right.
    
    **since**
    
        LibreOffice 6.3
    """

__all__ = ['WritingMode2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_supported_locales import XSupportedLocales as XSupportedLocales_5bda1056
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_meaning import XMeaning as XMeaning_d65e0c8c

class XThesaurus(XSupportedLocales_5bda1056):
    """
    allows for the retrieval of possible meanings for a given word and language.
    
    The meaning of a word is in essence a descriptive text for that word. Each meaning may have several synonyms where a synonym is a word (or small text) with the same or similar meaning.

    See Also:
        `API XThesaurus <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XThesaurus.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XThesaurus'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XThesaurus'

    @abstractmethod
    def queryMeanings(self, aTerm: str, aLocale: Locale_70d308fa, aProperties: PropertyValues_d6470ce6) -> typing.Tuple[XMeaning_d65e0c8c, ...]:
        """
        If the language is not supported, an com.sun.star.lang.IllegalArgumentException exception is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XThesaurus']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XPathSettings(XPropertySet_bc180bfa):
    """
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XPathSettings <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XPathSettings'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XPathSettings'

    @abstractproperty
    def Addin(self) -> str:
        """
        Specifies the directory that contains spreadsheet add-ins which use the old add-in API.
        """
        ...

    @abstractproperty
    def AutoCorrect(self) -> str:
        """
        The settings of the AutoCorrect dialog.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def AutoText(self) -> str:
        """
        The directory which contains the AutoText modules.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def Backup(self) -> str:
        """
        Automatic backup copies of documents are stored here.
        """
        ...

    @abstractproperty
    def BasePathShareLayer(self) -> str:
        """
        """
        ...

    @abstractproperty
    def BasePathUserLayer(self) -> str:
        """
        """
        ...

    @abstractproperty
    def Basic(self) -> str:
        """
        The Basic files, used by the AutoPilots, can be found here.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def Bitmap(self) -> str:
        """
        This directory contains the icons for the toolbars.
        """
        ...

    @abstractproperty
    def Config(self) -> str:
        """
        The configuration files are located here.
        
        This entry cannot be changed by the user in Office user interface.
        """
        ...

    @abstractproperty
    def Dictionary(self) -> str:
        """
        The provided dictionaries are stored here.
        """
        ...

    @abstractproperty
    def Favorite(self) -> str:
        """
        Path to save folder bookmarks.
        """
        ...

    @abstractproperty
    def Filter(self) -> str:
        """
        Specifies the directory where all the filters are stored.
        """
        ...

    @abstractproperty
    def Gallery(self) -> str:
        """
        Specifies the directories which contains the Gallery database and multimedia files.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def Graphic(self) -> str:
        """
        This directory is displayed when the dialog for opening a graphic or for saving a new graphic is called.
        """
        ...

    @abstractproperty
    def Help(self) -> str:
        """
        The path to the Office help files.
        """
        ...

    @abstractproperty
    def Linguistic(self) -> str:
        """
        The files that are necessary for the spell check are saved here.
        """
        ...

    @abstractproperty
    def Module(self) -> str:
        """
        This is the path for the modules.
        """
        ...

    @abstractproperty
    def Palette(self) -> str:
        """
        This is the path to the palette files *.SOB to *.SOF containing user-defined colors and patterns.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def Plugin(self) -> str:
        """
        Plugins are saved in these directories.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def Storage(self) -> str:
        """
        Mail, News files and other information (for example, about FTP Server) are stored here.
        """
        ...

    @abstractproperty
    def Temp(self) -> str:
        """
        The base url to the office temp-files.
        """
        ...

    @abstractproperty
    def Template(self) -> str:
        """
        The templates originate from these folders and sub-folders.
        
        The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def UIConfig(self) -> str:
        """
        Global directories to look for user interface configuration files.
        
        The user interface configuration will be merged with user settings stored in the directory specified by UserConfig. The value can be more than one path separated by a semicolon.
        """
        ...

    @abstractproperty
    def UserConfig(self) -> str:
        """
        Specifies the folder with the user settings.
        """
        ...

    @abstractproperty
    def UserDictionary(self) -> str:
        """
        The custom dictionaries are contained here.
        """
        ...

    @abstractproperty
    def Work(self) -> str:
        """
        The path of the work folder can be modified according to the user's needs.
        
        The path specified here can be seen in the Open or Save dialog.
        """
        ...


__all__ = ['XPathSettings']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_input_stream import XInputStream as XInputStream_98d40ab4

class XTextInputStream(XInputStream_98d40ab4):
    """
    Interface to read strings from a stream.
    
    This interfaces allows to read strings separated by delimiters and to read lines. The character encoding to be used can be set by setEncoding(). Default encoding is \"utf8\".

    See Also:
        `API XTextInputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XTextInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XTextInputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XTextInputStream'

    @abstractmethod
    def isEOF(self) -> bool:
        """
        Returns the EOF status.
        
        This method has to be used to detect if the end of the stream is reached.
        
        Important: This cannot be detected by asking for an empty string because that can be a valid return value of readLine() (if the line is empty) and readString() (if a delimiter is directly followed by the next one).

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readLine(self) -> str:
        """
        reads text until a line break (CR, LF, or CR/LF) or EOF is found and returns it as string (without CR, LF).
        
        The read characters are converted according to the encoding defined by setEncoding(). If EOF is already reached before calling this method an empty string is returned.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readString(self, Delimiters: typing.Tuple[str, ...], bRemoveDelimiter: bool) -> str:
        """
        reads text until one of the given delimiter characters or EOF is found and returns it as string (without delimiter).
        
        Important: CR/LF is not used as default delimiter! So if no delimiter is defined or none of the delimiters is found, the stream will be read to EOF. The read characters are converted according to the encoding defined by setEncoding(). If EOF is already reached before calling this method an empty string is returned.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def setEncoding(self, Encoding: str) -> None:
        """
        sets character encoding.
        """
        ...

__all__ = ['XTextInputStream']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
from abc import abstractproperty
from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2

class XNumericControl(XPropertyControl_3f260fe2):
    """
    defines the interface for an XPropertyControl which supports displaying and entering numerical values.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XNumericControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XNumericControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.XNumericControl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.inspection.XNumericControl'

    @abstractproperty
    def DecimalDigits(self) -> int:
        """
        describes the number of decimal digits to use for the value
        """
        ...

    @abstractproperty
    def DisplayUnit(self) -> int:
        """
        describes a com.sun.star.util.MeasureUnit to be applied for displaying values.
        
        Only a certain set of com.sun.star.util.MeasureUnit values is supported. In particular, every value which denotes a fraction of another unit (like 100th millimeters) cannot be used as DisplayUnit.
        """
        ...

    @abstractproperty
    def MaxValue(self) -> object:
        """
        describes the maximum value which is allowed to be entered in the control
        """
        ...

    @abstractproperty
    def MinValue(self) -> object:
        """
        describes the minimum value which is allowed to be entered in the control
        """
        ...

    @abstractproperty
    def ValueUnit(self) -> int:
        """
        describes a com.sun.star.util.MeasureUnit to be applied for transferring values.
        
        The core measurement unit for a property value might differ from the unit which is used by the control to display it. For instance, your property value might require that your values denote 100th millimeters, but to the user, you want to present the value as, say, inches. In this case, a numeric control can automatically handle the value conversion for you, if you give it a ValueUnit different from the DisplayUnit.
        """
        ...


__all__ = ['XNumericControl']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_hierarchical_property_set_info import XHierarchicalPropertySetInfo as XHierarchicalPropertySetInfo_ae271245

class XHierarchicalPropertySet(XInterface_8f010a43):
    """
    provides information about and access to the a hierarchy of properties from an implementation.
    
    Usually an object that implements this interface also implements XPropertySet and at least some of the properties have subproperties.
    
    This interface allows direct access to subsubproperties, ... up to an arbitrary nesting depth. Often the intermediate elements of the hierarchy implement XProperty.
    
    Each implementation specifies how the hierarchical property names, that are used to access the elements of the hierarchy, are formed.
    
    Commonly a notation similar to filesystem paths (separated by '/' slashes) or nested module names (separated by dots '.' or '.') is used.

    See Also:
        `API XHierarchicalPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XHierarchicalPropertySet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XHierarchicalPropertySet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XHierarchicalPropertySet'

    @abstractmethod
    def getHierarchicalPropertySetInfo(self) -> XHierarchicalPropertySetInfo_ae271245:
        """
        retrieve information about the hierarchy of properties
        """
        ...
    @abstractmethod
    def getHierarchicalPropertyValue(self, aHierarchicalPropertyName: str) -> object:
        """

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def setHierarchicalPropertyValue(self, aHierarchicalPropertyName: str, aValue: object) -> None:
        """
        sets the value of the property with the specified nested name.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XHierarchicalPropertySet']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.logging
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .log_record import LogRecord as LogRecord_b0c20b70
    from .x_log_formatter import XLogFormatter as XLogFormatter_e23d0d1d

class XLogHandler(XComponent_98dc0ab5):
    """
    provides possibilities to send LogRecords to an arbitrary output channel.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XLogHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XLogHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.logging'
    __ooo_full_ns__: str = 'com.sun.star.logging.XLogHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.logging.XLogHandler'

    @abstractmethod
    def flush(self) -> None:
        """
        flushes all buffered output of the handler
        
        Log handlers are allowed to buffer their output. Upon flush being called, they must flush all their buffers.
        """
        ...
    @abstractmethod
    def publish(self, Record: LogRecord_b0c20b70) -> bool:
        """
        publish the given log record at the handler's output channel.
        """
        ...
    @abstractproperty
    def Encoding(self) -> str:
        """
        specifies MIME charset name for the encoding to be used by this handler
        
        It depends on the concrete handler implementation whether or not this parameter is needed.
        """
        ...

    @abstractproperty
    def Formatter(self) -> XLogFormatter_e23d0d1d:
        """
        specifies the formatter to be used by this handler.
        """
        ...

    @abstractproperty
    def Level(self) -> int:
        """
        specifies the log level of this handler
        
        Different handlers can have different log levels, which again might be different from the log level of the XLogger for which the handlers are used.
        """
        ...


__all__ = ['XLogHandler']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XAutoscroll(XInterface_8f010a43):
    """
    Interface for autoscroll support.
    
    During Drag and Drop operations it is possible that a user may wish to drop the subject of the operation on a region of a scrollable GUI control that is not currently visible to the user.
    
    In such situations it is desirable that the GUI control detect this and institute a scroll operation in order to make obscured region(s) visible to the user. This feature is known as autoscrolling.
    
    If a GUI control is both an active DropTarget and is also scrollable, it can receive notifications of autoscrolling gestures by the user from the Drag and Drop system by implementing this interface.
    
    An autoscrolling gesture is initiated by the user by keeping the drag cursor motionless with a border region of the Component, referred to as the \"autoscrolling region\", for a predefined period of time, this will result in repeated scroll requests to the Component until the drag Cursor resumes its motion.

    See Also:
        `API XAutoscroll <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XAutoscroll.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XAutoscroll'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XAutoscroll'

    @abstractmethod
    def autoscroll(self, cursorLocationX: int, cursorLocationY: int) -> None:
        """
        Notify the component to autoscroll.
        """
        ...
    @abstractmethod
    def getAutoscrollRegion(self) -> object:
        """
        Returns the regions describing the autoscrolling region.
        """
        ...

__all__ = ['XAutoscroll']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.linguistic2.conversion_dictionary import ConversionDictionary as ConversionDictionary
from ...lo.linguistic2.conversion_dictionary_list import ConversionDictionaryList as ConversionDictionaryList
from ...lo.linguistic2.conversion_dictionary_type import ConversionDictionaryType as ConversionDictionaryType
from ...lo.linguistic2.conversion_direction import ConversionDirection as ConversionDirection
from ...lo.linguistic2.conversion_property_type import ConversionPropertyType as ConversionPropertyType
from ...lo.linguistic2.dictionary import Dictionary as Dictionary
from ...lo.linguistic2.dictionary_event import DictionaryEvent as DictionaryEvent
from ...lo.linguistic2.dictionary_event_flags import DictionaryEventFlags as DictionaryEventFlags
from ...lo.linguistic2.dictionary_list import DictionaryList as DictionaryList
from ...lo.linguistic2.dictionary_list_event import DictionaryListEvent as DictionaryListEvent
from ...lo.linguistic2.dictionary_list_event_flags import DictionaryListEventFlags as DictionaryListEventFlags
from ...lo.linguistic2.dictionary_type import DictionaryType as DictionaryType
from ...lo.linguistic2.hangul_hanja_conversion_dictionary import HangulHanjaConversionDictionary as HangulHanjaConversionDictionary
from ...lo.linguistic2.hyphenator import Hyphenator as Hyphenator
from ...lo.linguistic2.language_guessing import LanguageGuessing as LanguageGuessing
from ...lo.linguistic2.lingu_properties import LinguProperties as LinguProperties
from ...lo.linguistic2.lingu_service_event import LinguServiceEvent as LinguServiceEvent
from ...lo.linguistic2.lingu_service_event_flags import LinguServiceEventFlags as LinguServiceEventFlags
from ...lo.linguistic2.lingu_service_manager import LinguServiceManager as LinguServiceManager
from ...lo.linguistic2.number_text import NumberText as NumberText
from ...lo.linguistic2.proofreader import Proofreader as Proofreader
from ...lo.linguistic2.proofreading_iterator import ProofreadingIterator as ProofreadingIterator
from ...lo.linguistic2.proofreading_result import ProofreadingResult as ProofreadingResult
from ...lo.linguistic2.single_proofreading_error import SingleProofreadingError as SingleProofreadingError
from ...lo.linguistic2.spell_checker import SpellChecker as SpellChecker
from ...lo.linguistic2.spell_failure import SpellFailure as SpellFailure
from ...lo.linguistic2.thesaurus import Thesaurus as Thesaurus
from ...lo.linguistic2.x_available_locales import XAvailableLocales as XAvailableLocales
from ...lo.linguistic2.x_conversion_dictionary import XConversionDictionary as XConversionDictionary
from ...lo.linguistic2.x_conversion_dictionary_list import XConversionDictionaryList as XConversionDictionaryList
from ...lo.linguistic2.x_conversion_property_type import XConversionPropertyType as XConversionPropertyType
from ...lo.linguistic2.x_dictionary import XDictionary as XDictionary
from ...lo.linguistic2.x_dictionary1 import XDictionary1 as XDictionary1
from ...lo.linguistic2.x_dictionary_entry import XDictionaryEntry as XDictionaryEntry
from ...lo.linguistic2.x_dictionary_event_listener import XDictionaryEventListener as XDictionaryEventListener
from ...lo.linguistic2.x_dictionary_list import XDictionaryList as XDictionaryList
from ...lo.linguistic2.x_dictionary_list_event_listener import XDictionaryListEventListener as XDictionaryListEventListener
from ...lo.linguistic2.x_hyphenated_word import XHyphenatedWord as XHyphenatedWord
from ...lo.linguistic2.x_hyphenator import XHyphenator as XHyphenator
from ...lo.linguistic2.x_language_guessing import XLanguageGuessing as XLanguageGuessing
from ...lo.linguistic2.x_lingu_properties import XLinguProperties as XLinguProperties
from ...lo.linguistic2.x_lingu_service_event_broadcaster import XLinguServiceEventBroadcaster as XLinguServiceEventBroadcaster
from ...lo.linguistic2.x_lingu_service_event_listener import XLinguServiceEventListener as XLinguServiceEventListener
from ...lo.linguistic2.x_lingu_service_manager import XLinguServiceManager as XLinguServiceManager
from ...lo.linguistic2.x_lingu_service_manager2 import XLinguServiceManager2 as XLinguServiceManager2
from ...lo.linguistic2.x_meaning import XMeaning as XMeaning
from ...lo.linguistic2.x_number_text import XNumberText as XNumberText
from ...lo.linguistic2.x_possible_hyphens import XPossibleHyphens as XPossibleHyphens
from ...lo.linguistic2.x_proofreader import XProofreader as XProofreader
from ...lo.linguistic2.x_proofreading_iterator import XProofreadingIterator as XProofreadingIterator
from ...lo.linguistic2.x_searchable_dictionary import XSearchableDictionary as XSearchableDictionary
from ...lo.linguistic2.x_searchable_dictionary_list import XSearchableDictionaryList as XSearchableDictionaryList
from ...lo.linguistic2.x_set_spell_alternatives import XSetSpellAlternatives as XSetSpellAlternatives
from ...lo.linguistic2.x_spell_alternatives import XSpellAlternatives as XSpellAlternatives
from ...lo.linguistic2.x_spell_checker import XSpellChecker as XSpellChecker
from ...lo.linguistic2.x_spell_checker1 import XSpellChecker1 as XSpellChecker1
from ...lo.linguistic2.x_supported_languages import XSupportedLanguages as XSupportedLanguages
from ...lo.linguistic2.x_supported_locales import XSupportedLocales as XSupportedLocales
from ...lo.linguistic2.x_thesaurus import XThesaurus as XThesaurus



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.security
from __future__ import annotations
import typing
import uno
from abc import abstractmethod, abstractproperty
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_certificate_extension import XCertificateExtension as XCertificateExtension_6ead10f8
    from ..util.date_time import DateTime as DateTime_84de09d3
    from com.sun.star.security.CertificateKind import CertificateKindProto  # type: ignore

class XCertificate(XInterface_8f010a43):
    """
    Interface of a PKI Certificate.
    
    This interface represents a certificate (X.509 or OpenPGP) .
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API XCertificate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.XCertificate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.security.XCertificate'

    @abstractmethod
    def findCertificateExtension(self, oid: uno.ByteSequence) -> XCertificateExtension_6ead10f8:
        """
        Find an extension with an object identifier.
        """
        ...
    @abstractmethod
    def getCertificateUsage(self) -> int:
        """
        get the certificate usage.
        
        The return value is a set of bits, as defined in RFC3280 for the KeyUsage BIT STRING. Note the bit and byte order used in ASN.1, so for instance the bit dataEncipherment in KeyUsage, \"bit 3\", corresponds to CERT_DATA_ENCIPHERMENT_KEY_USAGE in Win32 and KU_DATA_ENCIPHERMENT in NSS, both with value 0x10.
        """
        ...
    @abstractproperty
    def Encoded(self) -> uno.ByteSequence:
        """
        the DER encoded form of the certificate
        """
        ...

    @abstractproperty
    def Extensions(self) -> typing.Tuple[XCertificateExtension_6ead10f8, ...]:
        """
        all extensions of a certificate.
        """
        ...

    @abstractproperty
    def IssuerUniqueID(self) -> uno.ByteSequence:
        """
        the issuer unique ID attribute of the certificate.
        """
        ...

    @abstractproperty
    def MD5Thumbprint(self) -> uno.ByteSequence:
        """
        the MD5 thumbprint
        """
        ...

    @abstractproperty
    def SHA1Thumbprint(self) -> uno.ByteSequence:
        """
        the SHA-1 thumbprint
        """
        ...

    @abstractproperty
    def SerialNumber(self) -> uno.ByteSequence:
        """
        the serial number attribute of the certificate.
        """
        ...

    @abstractproperty
    def SubjectPublicKeyValue(self) -> uno.ByteSequence:
        """
        the value of the subject public key
        """
        ...

    @abstractproperty
    def SubjectUniqueID(self) -> uno.ByteSequence:
        """
        the subject unique ID attribute of the certificate.
        """
        ...

    @abstractproperty
    def CertificateKind(self) -> CertificateKindProto:
        """
        the kind of certificate, X.509 or OpenPGP
        
        **since**
        
            LibreOffice 5.4
        """
        ...

    @abstractproperty
    def IssuerName(self) -> str:
        """
        the issuer name attribute of the certificate.
        """
        ...

    @abstractproperty
    def NotValidAfter(self) -> DateTime_84de09d3:
        """
        the validity NotAfter date attribute of the certificate.
        """
        ...

    @abstractproperty
    def NotValidBefore(self) -> DateTime_84de09d3:
        """
        the validity NotBefore date attribute of the certificate.
        """
        ...

    @abstractproperty
    def SignatureAlgorithm(self) -> str:
        """
        the signature algorithm
        """
        ...

    @abstractproperty
    def SubjectName(self) -> str:
        """
        the subject name attribute of the certificate.
        """
        ...

    @abstractproperty
    def SubjectPublicKeyAlgorithm(self) -> str:
        """
        the algorithm of the subject public key
        """
        ...

    @abstractproperty
    def Version(self) -> int:
        """
        the version number attribute of the certificate.
        """
        ...


__all__ = ['XCertificate']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DataPilotFieldLayoutMode(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.DataPilotFieldLayoutMode", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.DataPilotFieldLayoutMode``"""
        pass

    class DataPilotFieldLayoutModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.DataPilotFieldLayoutMode", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.DataPilotFieldLayoutMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import DataPilotFieldLayoutMode as DataPilotFieldLayoutMode
    else:
        # keep document generators happy
        from ...lo.sheet.data_pilot_field_layout_mode import DataPilotFieldLayoutMode as DataPilotFieldLayoutMode

    class DataPilotFieldLayoutModeEnum(IntEnum):
        """
        Enum of Const Class DataPilotFieldLayoutMode

        describes the layout mode of the data field
        """
        TABULAR_LAYOUT = DataPilotFieldLayoutMode.TABULAR_LAYOUT
        """
        Tabular layout mode is the layout, where each item's name is on the same row as the first item from the following field.
        
        Subtotals are always shown below an item's data in this mode.
        """
        OUTLINE_SUBTOTALS_TOP = DataPilotFieldLayoutMode.OUTLINE_SUBTOTALS_TOP
        """
        In outline layout mode, the items from the following field start in the row below an item's name, like in traditional database reports.
        
        Subtotals are shown at the top (on the same row as the item's name). When the subtotals take up more than one row (manually selected, or because there are several data fields), they are always shown below the item's data, regardless of the setting.
        """
        OUTLINE_SUBTOTALS_BOTTOM = DataPilotFieldLayoutMode.OUTLINE_SUBTOTALS_BOTTOM
        """
        In outline layout mode, the items from the following field start in the row below an item's name, like in traditional database reports.
        
        Subtotals are shown at the bottom (below the item's data, as in tabular layout mode). When the subtotals take up more than one row (manually selected, or because there are several data fields), they are always shown below the item's data, regardless of the setting.
        """

__all__ = ['DataPilotFieldLayoutMode', 'DataPilotFieldLayoutModeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..awt.size import Size as Size_576707ef
from .symbol_style import SymbolStyle as SymbolStyle_baa20bd3
from ..drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords_7ec5114b
from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc


class Symbol(object):
    """
    Struct Class

    properties that are used for DataSeries that display symbols.

    See Also:
        `API Symbol <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.Symbol'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.Symbol'
    """Literal Constant ``com.sun.star.chart2.Symbol``"""

    def __init__(self, Style: typing.Optional[SymbolStyle_baa20bd3] = SymbolStyle_baa20bd3.NONE, PolygonCoords: typing.Optional[PolyPolygonBezierCoords_7ec5114b] = UNO_NONE, StandardSymbol: typing.Optional[int] = 0, Graphic: typing.Optional[XGraphic_a4da0afc] = None, Size: typing.Optional[Size_576707ef] = UNO_NONE, BorderColor: typing.Optional[int] = 0, FillColor: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Style (SymbolStyle, optional): Style value.
            PolygonCoords (PolyPolygonBezierCoords, optional): PolygonCoords value.
            StandardSymbol (int, optional): StandardSymbol value.
            Graphic (XGraphic, optional): Graphic value.
            Size (Size, optional): Size value.
            BorderColor (int, optional): BorderColor value.
            FillColor (int, optional): FillColor value.
        """
        super().__init__()

        if isinstance(Style, Symbol):
            oth: Symbol = Style
            self.Style = oth.Style
            self.PolygonCoords = oth.PolygonCoords
            self.StandardSymbol = oth.StandardSymbol
            self.Graphic = oth.Graphic
            self.Size = oth.Size
            self.BorderColor = oth.BorderColor
            self.FillColor = oth.FillColor
            return

        kargs = {
            "Style": Style,
            "PolygonCoords": PolygonCoords,
            "StandardSymbol": StandardSymbol,
            "Graphic": Graphic,
            "Size": Size,
            "BorderColor": BorderColor,
            "FillColor": FillColor,
        }
        if kargs["PolygonCoords"] is UNO_NONE:
            kargs["PolygonCoords"] = None
        if kargs["Size"] is UNO_NONE:
            kargs["Size"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._style = kwargs["Style"]
        self._polygon_coords = kwargs["PolygonCoords"]
        self._standard_symbol = kwargs["StandardSymbol"]
        self._graphic = kwargs["Graphic"]
        self._size = kwargs["Size"]
        self._border_color = kwargs["BorderColor"]
        self._fill_color = kwargs["FillColor"]


    @property
    def Style(self) -> SymbolStyle_baa20bd3:
        """
        determines which of the following members determines the appearance of the symbol.
        """
        return self._style

    @Style.setter
    def Style(self, value: SymbolStyle_baa20bd3) -> None:
        self._style = value

    @property
    def PolygonCoords(self) -> PolyPolygonBezierCoords_7ec5114b:
        """
        The given polygon is used as symbol.
        """
        return self._polygon_coords

    @PolygonCoords.setter
    def PolygonCoords(self, value: PolyPolygonBezierCoords_7ec5114b) -> None:
        self._polygon_coords = value

    @property
    def StandardSymbol(self) -> int:
        """
        Use the nth standard symbol, if Style is set to SymbolStyle.STANDARD.
        
        If n is the number of standard symbols available in an implementation, the symbol number is StandardSymbol modulo n.
        
        The default implementation for example currently uses 8 different standard symbols that are matched to the numbers 0 to 7.
        """
        return self._standard_symbol

    @StandardSymbol.setter
    def StandardSymbol(self, value: int) -> None:
        self._standard_symbol = value

    @property
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        use this graphic as symbol
        """
        return self._graphic

    @Graphic.setter
    def Graphic(self, value: XGraphic_a4da0afc) -> None:
        self._graphic = value

    @property
    def Size(self) -> Size_576707ef:
        """
        The size of the symbol in 100th of a mm.
        """
        return self._size

    @Size.setter
    def Size(self, value: Size_576707ef) -> None:
        self._size = value

    @property
    def BorderColor(self) -> int:
        """
        The color used for drawing the border of symbols.
        
        Only effective if Style is SymbolStyle.AUTO, SymbolStyle.STANDARD or SymbolStyle.POLYGON.
        """
        return self._border_color

    @BorderColor.setter
    def BorderColor(self, value: int) -> None:
        self._border_color = value

    @property
    def FillColor(self) -> int:
        """
        The color used for filling symbols that contain closed polygons.
        
        Only effective if Style is SymbolStyle.AUTO, SymbolStyle.STANDARD or SymbolStyle.POLYGON.
        """
        return self._fill_color

    @FillColor.setter
    def FillColor(self, value: int) -> None:
        self._fill_color = value


__all__ = ['Symbol']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import uno
import typing


class SearchResult(object):
    """
    Struct Class


    See Also:
        `API SearchResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.SearchResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.SearchResult'
    """Literal Constant ``com.sun.star.util.SearchResult``"""

    def __init__(self, startOffset: typing.Optional[uno.ByteSequence] = (), endOffset: typing.Optional[uno.ByteSequence] = (), subRegExpressions: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            startOffset (uno.ByteSequence, optional): startOffset value.
            endOffset (uno.ByteSequence, optional): endOffset value.
            subRegExpressions (int, optional): subRegExpressions value.
        """
        super().__init__()

        if isinstance(startOffset, SearchResult):
            oth: SearchResult = startOffset
            self.startOffset = oth.startOffset
            self.endOffset = oth.endOffset
            self.subRegExpressions = oth.subRegExpressions
            return

        kargs = {
            "startOffset": startOffset,
            "endOffset": endOffset,
            "subRegExpressions": subRegExpressions,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._start_offset = kwargs["startOffset"]
        self._end_offset = kwargs["endOffset"]
        self._sub_reg_expressions = kwargs["subRegExpressions"]


    @property
    def startOffset(self) -> uno.ByteSequence:
        return self._start_offset

    @startOffset.setter
    def startOffset(self, value: uno.ByteSequence) -> None:
        self._start_offset = value

    @property
    def endOffset(self) -> uno.ByteSequence:
        return self._end_offset

    @endOffset.setter
    def endOffset(self, value: uno.ByteSequence) -> None:
        self._end_offset = value

    @property
    def subRegExpressions(self) -> int:
        """
        Number of subexpressions.
        
        If it is 0, then no match found; this value is 1 for ABSOLUTE and APPROXIMATE match. The start and endOffset are always dependent on the search direction.
        
        For example, if you search \"X\" in the text \"-X-\" the offsets are:
        
        Forward, the startOffset is inclusive, the endOffset exclusive. Backward, the startOffset is exclusive, the endOffset inclusive.
        
        For regular expressions it can be greater than 1. If the value is 1, startoffset[0] and endoffset[0] points to the matching sub string if value is > 1, still startoffset[0] and endoffset[0] points to the matching substring for whole regular expression startoffset[i] and endoffset[i] points to the matching substring of i th matching substring.
        """
        return self._sub_reg_expressions

    @subRegExpressions.setter
    def subRegExpressions(self, value: int) -> None:
        self._sub_reg_expressions = value


__all__ = ['SearchResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DeviceInfo(object):
    """
    Struct Class

    contains information about a device.

    See Also:
        `API DeviceInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1DeviceInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.DeviceInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.DeviceInfo'
    """Literal Constant ``com.sun.star.awt.DeviceInfo``"""

    def __init__(self, Width: typing.Optional[int] = 0, Height: typing.Optional[int] = 0, LeftInset: typing.Optional[int] = 0, TopInset: typing.Optional[int] = 0, RightInset: typing.Optional[int] = 0, BottomInset: typing.Optional[int] = 0, PixelPerMeterX: typing.Optional[float] = 0.0, PixelPerMeterY: typing.Optional[float] = 0.0, BitsPerPixel: typing.Optional[int] = 0, Capabilities: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Width (int, optional): Width value.
            Height (int, optional): Height value.
            LeftInset (int, optional): LeftInset value.
            TopInset (int, optional): TopInset value.
            RightInset (int, optional): RightInset value.
            BottomInset (int, optional): BottomInset value.
            PixelPerMeterX (float, optional): PixelPerMeterX value.
            PixelPerMeterY (float, optional): PixelPerMeterY value.
            BitsPerPixel (int, optional): BitsPerPixel value.
            Capabilities (int, optional): Capabilities value.
        """
        super().__init__()

        if isinstance(Width, DeviceInfo):
            oth: DeviceInfo = Width
            self.Width = oth.Width
            self.Height = oth.Height
            self.LeftInset = oth.LeftInset
            self.TopInset = oth.TopInset
            self.RightInset = oth.RightInset
            self.BottomInset = oth.BottomInset
            self.PixelPerMeterX = oth.PixelPerMeterX
            self.PixelPerMeterY = oth.PixelPerMeterY
            self.BitsPerPixel = oth.BitsPerPixel
            self.Capabilities = oth.Capabilities
            return

        kargs = {
            "Width": Width,
            "Height": Height,
            "LeftInset": LeftInset,
            "TopInset": TopInset,
            "RightInset": RightInset,
            "BottomInset": BottomInset,
            "PixelPerMeterX": PixelPerMeterX,
            "PixelPerMeterY": PixelPerMeterY,
            "BitsPerPixel": BitsPerPixel,
            "Capabilities": Capabilities,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._width = kwargs["Width"]
        self._height = kwargs["Height"]
        self._left_inset = kwargs["LeftInset"]
        self._top_inset = kwargs["TopInset"]
        self._right_inset = kwargs["RightInset"]
        self._bottom_inset = kwargs["BottomInset"]
        self._pixel_per_meter_x = kwargs["PixelPerMeterX"]
        self._pixel_per_meter_y = kwargs["PixelPerMeterY"]
        self._bits_per_pixel = kwargs["BitsPerPixel"]
        self._capabilities = kwargs["Capabilities"]


    @property
    def Width(self) -> int:
        """
        contains the width of the device in pixels.
        """
        return self._width

    @Width.setter
    def Width(self, value: int) -> None:
        self._width = value

    @property
    def Height(self) -> int:
        """
        contains the height of the device in pixels.
        """
        return self._height

    @Height.setter
    def Height(self, value: int) -> None:
        self._height = value

    @property
    def LeftInset(self) -> int:
        """
        contains the inset from the left.
        """
        return self._left_inset

    @LeftInset.setter
    def LeftInset(self, value: int) -> None:
        self._left_inset = value

    @property
    def TopInset(self) -> int:
        """
        contains the inset from the top.
        """
        return self._top_inset

    @TopInset.setter
    def TopInset(self, value: int) -> None:
        self._top_inset = value

    @property
    def RightInset(self) -> int:
        """
        contains the inset from the right.
        """
        return self._right_inset

    @RightInset.setter
    def RightInset(self, value: int) -> None:
        self._right_inset = value

    @property
    def BottomInset(self) -> int:
        """
        contains the inset from the bottom.
        """
        return self._bottom_inset

    @BottomInset.setter
    def BottomInset(self, value: int) -> None:
        self._bottom_inset = value

    @property
    def PixelPerMeterX(self) -> float:
        """
        contains the X-axis resolution of the device in pixel/meter.
        """
        return self._pixel_per_meter_x

    @PixelPerMeterX.setter
    def PixelPerMeterX(self, value: float) -> None:
        self._pixel_per_meter_x = value

    @property
    def PixelPerMeterY(self) -> float:
        """
        contains the Y-axis resolution of the device in pixel/meter.
        """
        return self._pixel_per_meter_y

    @PixelPerMeterY.setter
    def PixelPerMeterY(self, value: float) -> None:
        self._pixel_per_meter_y = value

    @property
    def BitsPerPixel(self) -> int:
        """
        contains the color-depth of the device.
        """
        return self._bits_per_pixel

    @BitsPerPixel.setter
    def BitsPerPixel(self, value: int) -> None:
        self._bits_per_pixel = value

    @property
    def Capabilities(self) -> int:
        """
        specifies special operations which are possible on the device.
        """
        return self._capabilities

    @Capabilities.setter
    def Capabilities(self, value: int) -> None:
        self._capabilities = value


__all__ = ['DeviceInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
from abc import abstractproperty
from ...awt.uno_control_edit_model import UnoControlEditModel as UnoControlEditModel_fd8e0dde
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ...text.text_range import TextRange as TextRange_90540a5f

class RichTextControl(UnoControlEditModel_fd8e0dde, FormControlModel_e2990d22, TextRange_90540a5f):
    """
    Service Class

    specifies a component which extends the com.sun.star.awt.UnoControlEditModel with capabilities to display and input formatted text.

    See Also:
        `API RichTextControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RichTextControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.RichTextControl'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HardLineBreaks(self) -> bool:
        """
        specifies whether text should be automatically wrapped to fit into the control.
        
        If set to TRUE, users need to manually press the enter key to insert a line break. If set to FALSE, text is automatically wrapped at the control border.
        """
        ...

    @abstractproperty
    def RichText(self) -> bool:
        """
        specifies whether the control should display the text including all its formatting.
        
        If this is set to FALSE, the control will act as ordinary com.sun.star.awt.UnoControlEditModel.
        
        If the property is set to TRUE, the control will ignore the following properties:
        """
        ...


__all__ = ['RichTextControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from ..beans.x_properties_change_notifier import XPropertiesChangeNotifier as XPropertiesChangeNotifier_7a7b111c
from ..beans.x_property_container import XPropertyContainer as XPropertyContainer_c600e71
from ..beans.x_property_set_info_change_notifier import XPropertySetInfoChangeNotifier as XPropertySetInfoChangeNotifier_d524130c
from ..container.x_child import XChild as XChild_a6390b07
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_command_info_change_notifier import XCommandInfoChangeNotifier as XCommandInfoChangeNotifier_6358106b
from .x_command_processor import XCommandProcessor as XCommandProcessor_dfe80d19
from .x_command_processor2 import XCommandProcessor2 as XCommandProcessor2_ed330d4b
from .x_content import XContent as XContent_79db0975
from .x_content_creator import XContentCreator as XContentCreator_c6b80c45

class HierarchyRootFolderContent(XPropertiesChangeNotifier_7a7b111c, XPropertyContainer_c600e71, XPropertySetInfoChangeNotifier_d524130c, XChild_a6390b07, XComponent_98dc0ab5, XCommandInfoChangeNotifier_6358106b, XCommandProcessor2_ed330d4b, XCommandProcessor_dfe80d19, XContent_79db0975, XContentCreator_c6b80c45):
    """
    Service Class

    A HCP Root Folder is the root container for all other HCP Folders and HCP Links.
    
    It always has the URL \"vnd.sun.star.hier:/\". A HCP Root Folder neither can't be created nor deleted by a UCB client.

    See Also:
        `API HierarchyRootFolderContent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1HierarchyRootFolderContent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.HierarchyRootFolderContent'
    __ooo_type_name__: str = 'service'


__all__ = ['HierarchyRootFolderContent']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue_517b1592

class EnhancedCustomShapeGeometry(ABC):
    """
    Service Class

    This service may be represented by a com.sun.star.beans.PropertyValue [].

    See Also:
        `API EnhancedCustomShapeGeometry <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeGeometry'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AdjustmentValues(self) -> typing.Tuple[EnhancedCustomShapeAdjustmentValue_517b1592, ...]:
        """
        This property specifies a sequence of Adjustment values.
        """
        ...

    @abstractproperty
    def Equations(self) -> typing.Tuple[str, ...]:
        """
        This property is describing the equations that are used, each equation can be referenced by com.sun.star.drawing.EnhancedCustomShapeParameter which are often used in Path, Extrusion and or Handle descriptions.
        """
        ...

    @abstractproperty
    def Extrusion(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        This property sequence is including the extrusion description, the properties are as same as specified in the service com.sun.star:drawing.EnhancedCustomShapeExtrusion.
        """
        ...

    @abstractproperty
    def Handles(self) -> typing.Tuple[PropertyValues_d6470ce6, ...]:
        """
        This property is describing the interaction handles that are used, each inner property sequence is having the same properties as they are specified in the service com.sun.star:drawing.EnhancedCustomShapeHandle.
        """
        ...

    @abstractproperty
    def Path(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        This property sequence is including the path description, the properties are as same as specified in the service com.sun.star:drawing.EnhancedCustomShapePath.
        """
        ...

    @abstractproperty
    def TextPath(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        This property sequence is including the text path description, the properties are as same as specified in the service com.sun.star:drawing.EnhancedCustomShapeTextPath.
        """
        ...

    @abstractproperty
    def MirroredX(self) -> bool:
        """
        This property specifies if the orientation of the shape is horizontal mirrored.
        """
        ...

    @abstractproperty
    def MirroredY(self) -> bool:
        """
        This property specifies if the orientation of the shape is vertical mirrored.
        """
        ...

    @abstractproperty
    def TextRotateAngle(self) -> float:
        """
        This property specifies the text rotation angle in degrees.
        
        The text rotation is added to the shape geometry rotation.
        """
        ...

    @abstractproperty
    def Type(self) -> str:
        """
        The Type attribute contains the name of a shape type.
        
        This name can be used to offer specialized user interfaces for certain classes of shapes, like for arrows, smileys, etc. The shape type is rendering engine dependent and does not influence the geometry of the shape. If the value of the draw:type attribute is non-primitive, then no shape type is available.
        """
        ...

    @abstractproperty
    def ViewBox(self) -> Rectangle_84b109e9:
        """
        This property describes the user space of the shape in its canonical form.
        """
        ...


__all__ = ['EnhancedCustomShapeGeometry']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.gallery
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_gallery_item import XGalleryItem as XGalleryItem_d5730caf
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class GalleryItem(XPropertySet_bc180bfa, XGalleryItem_d5730caf):
    """
    Service Class

    service to get access to the properties of a single Gallery item

    See Also:
        `API GalleryItem <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1gallery_1_1GalleryItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.gallery'
    __ooo_full_ns__: str = 'com.sun.star.gallery.GalleryItem'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Drawing(self) -> XComponent_98dc0ab5:
        """
        the drawing content of the Gallery item
        
        This is an optional property and may not available for every item
        """
        ...

    @abstractproperty
    def GalleryItemType(self) -> int:
        """
        The type of the Gallery item.
        """
        ...

    @abstractproperty
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        the graphic content of the Gallery item
        
        This is an optional property and may not available for every item
        """
        ...

    @abstractproperty
    def Thumbnail(self) -> XGraphic_a4da0afc:
        """
        the thumbnail of the Gallery item
        
        The thumbnail may be either a pixel or a vector graphic
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        the title of the Gallery item
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        the URL of the Gallery item
        
        The interpretation of the URL depends on the type of the Gallery item. In case of graphic and media items, the URL is a \"real\" URL, in case of drawings it is a private URL
        """
        ...


__all__ = ['GalleryItem']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.uno.deployment_exception import DeploymentException as DeploymentException
with suppress(ImportError):
    from ...dyn.uno.exception import Exception as Exception
with suppress(ImportError):
    from ...dyn.uno.naming_service import NamingService as NamingService
with suppress(ImportError):
    from ...dyn.uno.runtime_exception import RuntimeException as RuntimeException
with suppress(ImportError):
    from ...dyn.uno.security_exception import SecurityException as SecurityException
with suppress(ImportError):
    from ...dyn.uno.type_class import TypeClass as TypeClass
with suppress(ImportError):
    from ...dyn.uno.uik import Uik as Uik
with suppress(ImportError):
    from ...dyn.uno.x_adapter import XAdapter as XAdapter
with suppress(ImportError):
    from ...dyn.uno.x_aggregation import XAggregation as XAggregation
with suppress(ImportError):
    from ...dyn.uno.x_component_context import XComponentContext as XComponentContext
with suppress(ImportError):
    from ...dyn.uno.x_current_context import XCurrentContext as XCurrentContext
with suppress(ImportError):
    from ...dyn.uno.x_interface import XInterface as XInterface
with suppress(ImportError):
    from ...dyn.uno.x_naming_service import XNamingService as XNamingService
with suppress(ImportError):
    from ...dyn.uno.x_reference import XReference as XReference
with suppress(ImportError):
    from ...dyn.uno.x_unloading_preference import XUnloadingPreference as XUnloadingPreference
with suppress(ImportError):
    from ...dyn.uno.x_weak import XWeak as XWeak
